#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gtk2hs-buildtools
version:              0.13.12.0
visibility:           public
id:                   gtk2hs-buildtools-0.13.12.0-KQFey2PXfng9dJlAGN2irc
key:                  gtk2hs-buildtools-0.13.12.0-KQFey2PXfng9dJlAGN2irc
license:              GPL-2.0-only
copyright:            (c) 2001-2010 The Gtk2Hs Team
maintainer:           gtk2hs-devel@lists.sourceforge.net
author:               Axel Simon, Duncan Coutts, Manuel Chakravaty
stability:            stable
homepage:             http://projects.haskell.org/gtk2hs/
synopsis:
    Tools to build the Gtk2Hs suite of User Interface libraries.

description:
    This package provides a set of helper programs necessary to
    build the Gtk2Hs suite of libraries. These tools include
    a modified c2hs binding tool that is used to generate
    FFI declarations, a tool to build a type hierarchy that
    mirrors the C type hierarchy of GObjects found in glib,
    and a generator for signal declarations that are used
    to call back from C to Haskell. These tools are not needed
    to actually run Gtk2Hs programs.

category:             Development
abi:                  06d47976b8f61df9873fd59df7f51b5b
exposed:              True
exposed-modules:      Gtk2HsC2Hs Gtk2HsSetup HookGenerator TypeGen
hidden-modules:
    Paths_gtk2hs_buildtools BaseVersion Config Errors Binary DLists
    FastMutInt FileOps FNameOps Map Position Set UNames CIO State
    StateBase StateTrans Attributes Idents NameSpaces Lexers C CAST
    CAttrs CBuiltin CLexer CNames CParser CParserMonad CPretty CTokens
    CTrav CHS CHSLexer CInfo GBMonad GenBind GenHeader C2HSState
    Switches C2HSConfig Version

import-dirs:          /usr/lib/ghc-9.6.6/site-local/gtk2hs-buildtools-0.13.12.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/gtk2hs-buildtools-0.13.12.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/gtk2hs-buildtools-0.13.12.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gtk2hs-buildtools
hs-libraries:         HSgtk2hs-buildtools-0.13.12.0-KQFey2PXfng9dJlAGN2irc
depends:
    Cabal-3.10.3.0 array-0.5.6.0 base-4.18.2.1 containers-0.6.7
    directory-1.3.8.5 filepath-1.4.300.1
    hashtables-1.4.2-DD6PUgTalkM6mom3zoT5Rr pretty-1.1.3.6
    process-1.6.19.0 random-1.2.1.3-Ed9sqfiGJWrIk2dDIiP5zT

haddock-interfaces:
    /usr/share/doc/haskell-gtk2hs-buildtools/html/gtk2hs-buildtools.haddock

haddock-html:         /usr/share/doc/haskell-gtk2hs-buildtools/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

